__version__ = "0.2.3"
__git_commiter_name__ = "Arnon Yaari"
__git_commiter_email__ = "arnony@infinidat.com"
__git_branch__ = '(HEAD detached at v0.2.3)'
__git_remote_tracking_branch__ = '(No remote tracking)'
__git_remote_url__ = '(Not remote tracking)'
__git_head_hash__ = '4fef13f01e4ccaef0143751d65cca244fbf06bdd'
__git_head_subject__ = 'Finished release v0.2.3.'
__git_head_message__ = ''
__git_dirty_diff__ = ''
__git_commit_date__ = '2015-07-08 11:59:32'
